pilas.motores.motor_qt.MusicaDeshabilitada

Package pilas :: Package motores :: Module motor_qt :: Class MusicaDeshabilitada |
[hide private]
[frames] | no frames]

# Class MusicaDeshabilitada

source code

    SonidoDeshabilitado --+
                          |
                         MusicaDeshabilitada

Instance Methods | [hide private]
__init__(self, media, ruta) | source code
Inherited from `SonidoDeshabilitado`: `continuar`, `detener`, `pausar`, `reproducir`

Class Variables | [hide private]
Inherited from `SonidoDeshabilitado`: `deshabilitado`

Method Details | [hide private]

### __init__(self, media, ruta) (Constructor) | source code
Overrides: SonidoDeshabilitado.__init__